@@ -84,6 +84,23 @@ public:
         return !(a == b);
     }
 
+    /// Give points an (arbitrary) order.
+    [[nodiscard]] constexpr friend bool operator<(point_t a, point_t b) noexcept
+    {
+        if (a.x() == b.x()) {
+            return a.y() < b.y();
+        }
+        return a.x() < b.x();
+    }
+
+    [[nodiscard]] constexpr friend bool operator>(point_t a, point_t b) noexcept
+    {
+        if (a.x() == b.x()) {
+            return a.y() > b.y();
+        }
+        return a.x() > b.x();
+    }
+
 private:
     double m_x = 0.0;
     double m_y = 0.0;
@@ -403,16 +420,4 @@ std::size_t dimension(geometry_t const &geom);
 
 } // namespace geom
 
-// This magic is used for visiting geometries. For an explanation see for
-// instance here:
-// https://arne-mertz.de/2018/05/overload-build-a-variant-visitor-on-the-fly/
-template <class... Ts>
-struct overloaded : Ts...
-{
-    using Ts::operator()...;
-};
-
-template <class... Ts>
-overloaded(Ts...) -> overloaded<Ts...>;
-
 #endif // OSM2PGSQL_GEOM_HPP
